@@ -1,11 +1,3 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
-
 import logging
 from typing import (
     NoReturn,
@@ -21,8 +13,8 @@ from cached_property import (
     cached_property,
 )
 
-from minos.api_gateway.common import (
-    MinosConfig,
+from .config import (
+    ApiGatewayConfig,
 )
 
 logger = logging.getLogger(__name__)
@@ -31,7 +23,7 @@ logger = logging.getLogger(__name__)
 class EntrypointLauncher:
     """EntryPoint Launcher class."""
 
-    def __init__(self, config: MinosConfig, services: tuple, *args, **kwargs):
+    def __init__(self, config: ApiGatewayConfig, services: tuple, *args, **kwargs):
         self.config = config
         self.services = services
 
